

# Replication material for 
# Institutional Reform and Public Attitudes toward EU Decision Making

library(cjoint)
library(rms)
library(data.table)


rm(list = ls())

platform <- "/Users/davidhilpert/Dropbox/sfb/data/Hiwis - Hahm/Konstantin + Manuel/GIP + Survey Related/Survey - 13 Countries/analysis/scripts/ejpr_replication_material"
outpath <- paste0(platform, "/output/")



# load data
load(paste0(platform, "/ejpr_data.RData"))


# helper script: information about chosen party from comparative manifesto project (cmp) ####
cmp <- read.csv(paste0(platform, "/external data/cmp17b.csv"), stringsAsFactors = F, encoding = "UTF-8" )

countries <- c("Austria", "Czech Republic", "Denmark", "France", "Germany", "Greece", "Hungary", "Ireland", "Italy", "Netherlands", "Poland", "Spain", "Sweden")

cmp <- cmp[as.Date(cmp$date) >= 200604,] # Austria 2008, Italy 2006
cmp <- subset(cmp, select = c("countryname", "date", "party", "partyname", "partyabbrev", "parfam", "per108", "per110", "rile"))


lastobs <- aggregate(cmp$date, by = list(cmp$party), max)
names(lastobs) <- c("party", "mostrecent")
cmp <- merge(cmp, lastobs, all.x = T, by = "party")
cmp <- cmp[cmp$date == cmp$mostrecent,]
cmp$mostrecent <- cmp$countryname <- NULL
rm(lastobs)

fin1 <- merge(fin1, cmp, all.x = T, by.x = "cmp_party_id", by.y = "party")

# by eu position of supported party (2019, cmp)
fin1$euplain <- fin1$per108 - fin1$per110

fin1$eucmp_ind <- NA
fin1$eucmp_ind[fin1$euplain <= quantile(fin1$euplain, .33, na.rm = T)] <- -1 
fin1$eucmp_ind[fin1$euplain > quantile(fin1$euplain, .33, na.rm = T) & fin1$euplain < quantile(fin1$euplain, .67, na.rm = T)] <- 0
fin1$eucmp_ind[fin1$euplain >= quantile(fin1$euplain, .67, na.rm = T) ] <- 1
fin1$eucmp_ind <- as.factor(fin1$eucmp_ind)
table(fin1$eucmp_ind)

rm(cmp)





# ANALYSIS ####

# prepare conjoint design 
# attributes
attribute_list <- list()
attribute_list[["proposal"]] <- c("The European Commission", "The European Commission_ the European Parliament_ or the member states (represented in the Council of the EU)", 
                                  "The European Parliament", "The member states (represented in the Council of the EU)")
attribute_list[["adoption"]] <- c("The European Commission", "The European Parliament", "The member states (represented in the Council of the EU)", "The member states (represented in the Council of the EU) and the European Parliament")
attribute_list[["voting"]] <- c("Member states decide unanimously", "Member states decide with majority vote")
attribute_list[["sanction"]] <- c("National courts", "Representatives of the EU and affected member states", "The Court of Justice of the European Union")

# baselines
baselines <- list()
baselines$proposal <- "The European Commission"
baselines$adoption <- "The member states (represented in the Council of the EU) and the European Parliament"
baselines$voting <- "Member states decide with majority vote"
baselines$sanction <- "The Court of Justice of the European Union"

# constraints
constraint_list <- list()

# for ols
fin1$forlm_proposal <- fin1$proposal
fin1$forlm_adoption <- relevel(fin1$adoption, 4)
fin1$forlm_voting <- relevel(fin1$voting, 2)
fin1$forlm_sanction <- relevel(fin1$sanction, 3)

levels(fin1$forlm_proposal)[levels(fin1$forlm_proposal) == "The European Commission"] <- "COM"
levels(fin1$forlm_proposal)[levels(fin1$forlm_proposal) == "The European Commission_ the European Parliament_ or the member states (represented in the Council of the EU)"] <- "COM, EP or Council"
levels(fin1$forlm_proposal)[levels(fin1$forlm_proposal) == "The European Parliament"] <- "EP"
levels(fin1$forlm_proposal)[levels(fin1$forlm_proposal) == "The member states (represented in the Council of the EU)"] <- "Council"
fin1$forlm_proposal <- factor(fin1$forlm_proposal, levels = c("COM", "COM, EP or Council", "Council", "EP"))

levels(fin1$forlm_adoption)[levels(fin1$forlm_adoption) == "The European Commission"] <- "COM"
levels(fin1$forlm_adoption)[levels(fin1$forlm_adoption) == "The European Parliament"] <- "EP"
levels(fin1$forlm_adoption)[levels(fin1$forlm_adoption) == "The member states (represented in the Council of the EU)"] <- "Council"
levels(fin1$forlm_adoption)[levels(fin1$forlm_adoption) == "The member states (represented in the Council of the EU) and the European Parliament"] <- "Council and EP"
fin1$forlm_adoption <- factor(fin1$forlm_adoption, levels = c("Council and EP", "Council", "COM", "EP"))

levels(fin1$forlm_voting)[levels(fin1$forlm_voting) == "Member states decide with majority vote"] <- "QMV"
levels(fin1$forlm_voting)[levels(fin1$forlm_voting) == "Member states decide unanimously"] <- "Unanimity"

levels(fin1$forlm_sanction)[levels(fin1$forlm_sanction) == "The Court of Justice of the European Union"] <- "CJEU"
levels(fin1$forlm_sanction)[levels(fin1$forlm_sanction) == "Representatives of the EU and affected member states"] <- "EU-representatives and governments"


# pooled analysis ####
# default: uniform design
summary(m1 <- amce(dv ~ (proposal + adoption + voting + sanction), 
                   data = fin1, 
                   respondent.id = "obsnum", 
                   cluster = T, 
                   baselines = baselines))

out <- summary(m1)[[1]]
out <- out[,c(1:4)]
out <- out[c(grep("proposal", out$Attribute), grep("adoption", out$Attribute), grep("voting", out$Attribute), grep("sanction", out$Attribute)),]
# reorder
out <- out[c(1,3,2, 6,4,5, 7:9),]
out <- rbind(NA, 0, out[1:3,],
             NA, NA, 0, out[4:6,],
             NA, NA, 0, out[7,],
             NA, NA, 0, out[8:9,]) 
# save results for entropy balancing 
save_for_later <- out

# Figure 2

tiff(paste0(outpath,"fig2_pooled.tif"), width = 19, height = 10, units = 'cm',compression = "lzw", res = 300)
par(mar=c(4,6,3,0), oma=c(0,0,0,0), mfrow=c(1,1))
plot(1,1,xlim = c(-.3,.3), ylim = c(0,20), axes = F, xlab = "Effect on Pr(Institutional design preferred)", ylab = "",
     main = paste("Pooled analysis, J= ", m1$numrespondents, ", N=", nrow(m1$data), sep = ""), cex.main=.75, cex.lab = 1, font = 2)
for (i in 1:nrow(out)){
  segments(out[i,3]-1.96*out[i,4],21-i,
           out[i,3]+1.96*out[i,4],21-i, lwd = 3, col = "black")
  points(out[i,3],21-i, pch=16, cex=.6)
}

segments(0,0,0,20, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)
text(x=-.2, y=c(4,8,14,20),labels=c("SANCTIONING", "VOTING", "ADOPTION", "PROPOSAL"), srt=0, adj=1, xpd=TRUE, cex = .75, font = 2)
text(x=-.2, y=c(16:19),labels=c("Parliament", "Council", "Commission, Parliament, or Council", "(Commission)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=-.2, y=c(10:13),labels=c("Parliament", "Commission", "Council", "(Council and Parliament)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=-.2, y=c(6,7),labels=c("Council unanimity", "(Majority of member states)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=-.2, y=c(1:3),labels=c("EU-representatives and governments", "National courts", "(Court of Justice)"), srt=0, adj=1, xpd=TRUE, cex = .75)
dev.off()



# country-level analyses ####
fin1$nat_ext <- fin1$nat
fin1$nat_ext[fin1$nat == "at"] <- "Austria"
fin1$nat_ext[fin1$nat == "cz"] <- "Czech Rep."
fin1$nat_ext[fin1$nat == "de"] <- "Germany"
fin1$nat_ext[fin1$nat == "dk"] <- "Denmark"
fin1$nat_ext[fin1$nat == "es"] <- "Spain"
fin1$nat_ext[fin1$nat == "fr"] <- "France"
fin1$nat_ext[fin1$nat == "gr"] <- "Greece"
fin1$nat_ext[fin1$nat == "hu"] <- "Hungary"
fin1$nat_ext[fin1$nat == "ie"] <- "Ireland"
fin1$nat_ext[fin1$nat == "it"] <- "Italy"
fin1$nat_ext[fin1$nat == "nl"] <- "Netherlands"
fin1$nat_ext[fin1$nat == "pl"] <- "Poland"
fin1$nat_ext[fin1$nat == "sv"] <- "Sweden"
countries <- sort(unique(fin1$nat_ext))


# now loops through countries in alphabetical order
country_results <- list()
for (i in 1:length(countries)){
  tmp <- fin1[fin1$nat_ext == countries[i],]
  ana_c <- amce(dv ~ (proposal + adoption + voting + sanction), 
                data = tmp, 
                respondent.id = "obsnum", 
                cluster = T, 
                baselines = baselines)
  country_results[[i]] <- ana_c
}

country_n <- NA
outlist <- list()
for (i in 1:13){
  country_n[i] <- country_results[[i]]$numrespondents
  
  outlist[[i]] <- summary(country_results[[i]])[[1]][,1:4]
  outlist[[i]] <- outlist[[i]][c(grep("proposal", outlist[[i]]$Attribute), grep("adoption", outlist[[i]]$Attribute), grep("voting", outlist[[i]]$Attribute), grep("sanction", outlist[[i]]$Attribute)),]
  outlist[[i]] <- outlist[[i]][c(1,3,2, 6,4,5, 7:9),]
  outlist[[i]] <- outlist[[i]][,3:4]
}


# Figure 4: country analysis ####
locs <- c(18:16, 12:10,6,2:1)
col <- c("grey5", "grey70", "grey25", "grey45")

tiff(paste0(outpath,"fig4_bycountry.tif"), width = 19, height = 10, units = 'cm',compression = "lzw", res = 300)
par(mar=c(4,0,1,0),oma=c(1,1,1,1), mfrow=c(1,5))
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=.75, cex.lab = .5)

text(x=0.2, y=c(4,8,14,20),labels=c("SANCTIONING", "VOTING", "ADOPTION", "PROPOSAL"), srt=0, adj=1, xpd=TRUE, cex = .75, font=2) 
text(x=0.2, y=c(16,17,19),labels=c("Parliament", "Council", "(Commission)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=0.2, y=c(18),labels=c("Commission, Parliament, or Council"), srt=0, adj=1, xpd=TRUE, cex = .55)
text(x=0.2, y=c(10:13),labels=c("Parliament", "Commission", "Council", "(Council and Parliament)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=0.2, y=c(6,7),labels=c("Council unanimity", "(Majority of member states)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=0.2, y=c(2:3),labels=c("National courts", "(Court of Justice)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=0.2, y=c(1),labels=c("EU-representatives and governments"), srt=0, adj=1, xpd=TRUE, cex = .55)


# Northern (Eurozone)
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"Northern (Eurozone)",cex=.75)
segments(0,0,0,19.5, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

points(rep(0,4), c(19,13,7,3), pch = 16, cex = 1)
for (i in c(1,5,8,10)){
  j <- which( c(1,5,8,10) == i)
  segments(outlist[[i]][,1]-1.96*outlist[[i]][,2],locs+.2-(.15*j),
           outlist[[i]][,1]+1.96*outlist[[i]][,2],locs+.2-.15*j, lwd = 1, col = col[j])
  points(outlist[[i]][,1],locs+.2-.15*j, pch=14+j, cex = .9)
}

legend(-.2, 22.5, legend=c(paste0(countries[c(1,5,8,10)], ", N=", country_n[c(1,5,8,10)]) ),  
       col = col, cex = .75, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white", pch=NA)

legend(-.2, 22.5, legend=c(NA,NA,NA,NA ),  
       col = "black", cex = .75, lwd=c(NA,NA,NA,NA), box.lwd = 0, box.col = "white", pch=14+1:4, bty='n', pt.cex=1)



# Northern (non-Eurozone)
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"Northern (non-Eurozone)",cex=.75)
segments(0,0,0,19.5, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

points(rep(0,4), c(19,13,7,3), pch = 16, cex = 1)
for (i in c(3,13)){
  j <- which( c(3,13) == i)
  segments(outlist[[i]][,1]-1.96*outlist[[i]][,2],locs+.2-(.15*j),
           outlist[[i]][,1]+1.96*outlist[[i]][,2],locs+.2-.15*j, lwd = 1, col = col[j])
  points(outlist[[i]][,1],locs+.2-.15*j, pch=14+j, cex = .9)
}

legend(-.2, 22.5, legend=c(paste0(countries[c(3,13)], ", N=", country_n[c(3,13)]) ),  
       col = col, cex = .75, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white", pch=NA)

legend(-.2, 22.5, legend=c(NA,NA ),  
       col = "black", cex = .75, lwd=c(NA,NA), box.lwd = 0, box.col = "white", pch=14+1:4, bty='n', pt.cex=1)


# Eastern
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"Eastern",cex=.75)
segments(0,0,0,19.5, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

points(rep(0,4), c(19,13,7,3), pch = 16, cex = 1)
for (i in c(2,7,11)){
  j <- which( c(2,7,11) == i)
  segments(outlist[[i]][,1]-1.96*outlist[[i]][,2],locs+.2-(.15*j),
           outlist[[i]][,1]+1.96*outlist[[i]][,2],locs+.2-.15*j, lwd = 1, col = col[j])
  points(outlist[[i]][,1],locs+.2-.15*j, pch=14+j, cex = .9)
}

legend(-.2, 22.5, legend=c(paste0(countries[c(2,7,11)], ", N=", country_n[c(2,7,11)]) ),  
       col = col, cex = .75, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white", pch=NA)

legend(-.2, 22.5, legend=c(NA,NA,NA ),  
       col = "black", cex = .75, lwd=c(NA,NA,NA), box.lwd = 0, box.col = "white", pch=14+1:4, bty='n', pt.cex=1)


# Southern
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"Southern",cex=.75)
segments(0,0,0,19.5, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

points(rep(0,4), c(19,13,7,3), pch = 16, cex = 1)
for (i in c(4,6,9,12)){
  j <- which( c(4,6,9,12) == i)
  segments(outlist[[i]][,1]-1.96*outlist[[i]][,2],locs+.2-(.15*j),
           outlist[[i]][,1]+1.96*outlist[[i]][,2],locs+.2-.15*j, lwd = 1, col = col[j])
  points(outlist[[i]][,1],locs+.2-.15*j, pch=14+j, cex = .9)
}

legend(-.2, 22.5, legend=c(paste0(countries[c(4,6,9,12)], ", N=", country_n[c(4,6,9,12)]) ),  
       col = col, cex = .75, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white", pch=NA)

legend(-.2, 22.5, legend=c(NA,NA,NA,NA ),  
       col = "black", cex = .75, lwd=c(NA,NA,NA,NA), box.lwd = 0, box.col = "white", pch=14+1:4, bty='n', pt.cex=1)

title(main = "", outer = T,
      xlab = "Effect on Pr(Institutional design preferred)",
      line = -1, cex.lab = 1, cex.main = .75)
dev.off()




# probability profiles ####
s1 <- ols(dv ~ forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction, data = fin1, x = TRUE, y = T)
(s1_cl <- robcov(s1, cluster = fin1$obsnum))
fit <- predict(s1_cl, se.fit = TRUE)
fin1$fit <- fit$linear.predictors
fin1$se <- fit$se.fit


# status quo profile
fit_sq <- unique(fin1$fit[fin1$proposal == "The European Commission" & 
                            fin1$adoption == "The member states (represented in the Council of the EU) and the European Parliament" & 
                            fin1$voting == "Member states decide with majority vote" & 
                            fin1$sanction == "The Court of Justice of the European Union"])

# also: profiles with (quasi-) minimum, maximum probability
columns <- which(colnames(fin1) %in% c("proposal", "adoption", "voting", "sanction", "fit", "se"))
profile <- fin1[fin1$fit == min(fin1$fit) | 
                  fin1$fit == max(fin1$fit) | 
                  fin1$fit == fit_sq |  
                  # profile with minimum absolute distance from 50% mark
                  fin1$fit == sort(unique(fin1$fit))[ which(min(abs(sort(unique(fin1$fit)) - .5)) == abs(sort(unique(fin1$fit)) - .5) )]
                , 
                columns] 

# retain unique values
profile_u <- profile[!duplicated(profile),] # leaves 4 profiles
# requires data table: sort 
setorder(profile_u, fit)

profile_u$proposal <- as.character(profile_u$proposal)
profile_u$proposal[profile_u$proposal == "The European Commission"] <- "Commission" 
profile_u$proposal[profile_u$proposal == "The European Parliament"] <- "Parliament" 
profile_u$proposal[profile_u$proposal == "The European Commission_ the European Parliament_ or the member states (represented in the Council of the EU)"] <- "Commission, Parliament or Council" 

profile_u$adoption <- as.character(profile_u$adoption)
profile_u$adoption[profile_u$adoption == "The European Commission"] <- "Commission" 
profile_u$adoption[profile_u$adoption == "The member states (represented in the Council of the EU) and the European Parliament"] <- "Council and Parliament" 

profile_u$sanction <- as.character(profile_u$sanction)
profile_u$sanction[profile_u$sanction == "The Court of Justice of the European Union"] <- "CJEU" 


# Figure 3
tiff(paste0(outpath,"fig3_probprofiles.tif"), width = 19, height = 10, units = 'cm',compression = "lzw", res = 300)
par(mfrow = c(1,1))
plot(1,1, xlim = c(0.2,0.8), ylim = c(1,5), type = 'n', axes = F, ylab = "", xlab = "Pr(Institutional design preferred)")
for (i in 1:nrow(profile_u)){
  segments(profile_u[i,5] - 2*profile_u[i,6], i, profile_u[i,5] + 2*profile_u[i,6], i)
  points(profile_u[i,5], i, pch=16, cex = .5)
  text(profile_u[i,5], i+.7, labels = profile_u[i,1], cex = .65)
  text(profile_u[i,5], i+.5, labels = profile_u[i,2], cex = .65)
  text(profile_u[i,5], i+.3, labels = profile_u[i,3], cex = .65)
  text(profile_u[i,5], i+.1, labels = profile_u[i,4], cex = .65)
}
axis(1, seq(0,1,by=.2))
segments(.5,0,.5, 5, col = "grey")
dev.off()




# now by country 
profile_cu <- list()
for ( i in 1:length(countries)){
  tmp <- fin1[fin1$nat_ext == countries[i],]
  
  sc <- ols(dv ~ proposal + adoption + voting + sanction, data = tmp, x = TRUE)
  sc_cl <- robcov(sc, cluster = tmp$obsnum)
  
  fit <- predict(sc_cl, se.fit = TRUE)
  tmp$fit <- fit$linear.predictors
  tmp$se <- fit$se.fit
  
  # status quo profile
  fit_sq <- unique(tmp$fit[tmp$proposal == "The European Commission" & 
                             tmp$adoption == "The member states (represented in the Council of the EU) and the European Parliament" & 
                             tmp$voting == "Member states decide with majority vote" & 
                             tmp$sanction == "The Court of Justice of the European Union"])
  
  # also: profiles with maximum probability
  profile_c <- tmp[tmp$fit == max(tmp$fit) | 
                     tmp$fit == fit_sq
                   ,
                   columns]
  
  profile_cu[[i]] <- profile_c[!duplicated(profile_c),] # leaves 4 profiles
  profile_cu[[i]] <- cbind(profile_cu[[i]], nat_ext=unique(tmp$nat_ext))
  
}
rm(columns)


profile_cu <- do.call(rbind, profile_cu)
profile_cu$proposal <- as.character(profile_cu$proposal)
profile_cu$proposal[profile_cu$proposal == "The European Commission"] <- "Commission" 
profile_cu$proposal[profile_cu$proposal == "The European Parliament"] <- "Parliament" 
profile_cu$proposal[profile_cu$proposal == "The European Commission_ the European Parliament_ or the member states (represented in the Council of the EU)"] <- "Commission, Parliament or Council" 
profile_cu$proposal[profile_cu$proposal == "The member states (represented in the Council of the EU)"] <- "Council" 

profile_cu$adoption <- as.character(profile_cu$adoption)
profile_cu$adoption[profile_cu$adoption == "The European Commission"] <- "Commission" 
profile_cu$adoption[profile_cu$adoption == "The member states (represented in the Council of the EU) and the European Parliament"] <- "Council and Parliament" 
profile_cu$adoption[profile_cu$adoption == "The member states (represented in the Council of the EU)"] <- "Council" 

profile_cu$sanction <- as.character(profile_cu$sanction)
profile_cu$sanction[profile_cu$sanction == "The Court of Justice of the European Union"] <- "CJEU" 


setorder(profile_cu, fit)
# status quo evaluation
sq <- profile_cu[profile_cu$proposal == "Commission" & profile_cu$adoption == "Council and Parliament" & profile_cu$voting == "Member states decide with majority vote" & profile_cu$sanction == "CJEU", ]


tiff(paste0(outpath,"fig5_sq_bycountry.tif"), width = 19, height = 10, units = 'cm',compression = "lzw", res = 300)
par(mfrow = c(1,1))
plot(1,1, xlim = c(0.2,0.8), ylim = c(2.5,4), type = 'n', axes = F, ylab = "", xlab = "Pr(Status quo preferred)")
for (i in 1:nrow(sq)){
  segments(sq[i,5] - 2*sq[i,6], 4-i/10, 
           sq[i,5] + 2*sq[i,6], 4-i/10, lwd = 2)
  points(sq[i,5], 4-i/10, pch=16, cex = .5)
  text(sq[i,5]-.075, 4-i/10, labels = sq[i,7], cex = .75)
}
segments(.5,0,.5, 4, col = "grey")
axis(1, seq(0,1,by=.2))
dev.off()


# Table 2
fortable2 <- profile_cu[profile_cu$proposal != "Commission",]
fortable2[order(fortable2$proposal),]





# SUBGROUP ANALYSES ####

# personal benefit
il1 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*person_ind, data = fin1[!is.na(fin1$person_ind),], x = T , y = T)
il1 <- robcov(il1, cluster = fin1$obsnum[!is.na(fin1$person_ind)])
# country benefit
il2 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*country_ind, data = fin1[!is.na(fin1$country_ind),], x = T , y = T)
il2 <- robcov(il2, cluster = fin1$obsnum[!is.na(fin1$country_ind)])
# national attachment
il3 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*cntry_attch_ind, data = fin1[!is.na(fin1$cntry_attch_ind),], x = T , y = T)
il3 <- robcov(il3, cluster = fin1$obsnum[!is.na(fin1$cntry_attch_ind)])
# procedural knowledge (subjective)
il4 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*know_subj_ind, data = fin1[!is.na(fin1$know_subj_ind),], x = T , y = T)
il4 <- robcov(il4, cluster = fin1$obsnum[!is.na(fin1$know_subj_ind)])
# EU knowledge (objective)
il5 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*know_obj_ind, data = fin1[!is.na(fin1$know_obj_ind),], x = T , y = T)
il5 <- robcov(il5, cluster = fin1$obsnum[!is.na(fin1$know_obj_ind)])
# Satisfaction with government performance 
il6 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*satis_ind, data = fin1[!is.na(fin1$satis_ind),], x = T , y = T)
il6 <- robcov(il6, cluster = fin1$obsnum[!is.na(fin1$satis_ind)])
# Education
il7 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*edu_ind, data = fin1[!is.na(fin1$edu_ind),], x = T , y = T)
il7 <- robcov(il7, cluster = fin1$obsnum[!is.na(fin1$edu_ind)])
# pro eu party support (cmp)
il8 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*eucmp_ind, data = fin1[!is.na(fin1$eucmp_ind),], x = T , y = T)
il8 <- robcov(il8, cluster = fin1$obsnum[!is.na(fin1$eucmp_ind)])
# left right self placement
il9 <- ols(dv ~ (forlm_proposal + forlm_adoption + forlm_voting + forlm_sanction)*leriself_ind, data = fin1[!is.na(fin1$leriself_ind),], x = T , y = T)
il9 <- robcov(il9, cluster = fin1$obsnum[!is.na(fin1$leriself_ind)])



outstorage <- list()
k <- 1
for  (il in list(il1,il2,il3,il4,il5,il6,il7,il8,il9)){
  # cluster standard errors
  main <- il$coefficients[-grep("\\*", names(il$coefficients))]
  main <- main[grep("forlm", names(main))]
  
  intr <- il$coefficients[grep("\\*", names(il$coefficients))]
  if (length(intr) > 9){
    intr <- intr[grep("1", names(intr))]
  }
  
  coefs1 <- main
  coefs2 <- main + intr
  
  # ses
  estvar  <- vcov(il)
  ses1 <- sqrt(diag(estvar))[names(sqrt(diag(estvar))) %in% names(main)]
  ses2 <- sqrt(diag(estvar[rownames(estvar) %in% names(main) , colnames(estvar) %in% names(main)] +
                      estvar[rownames(estvar) %in% names(intr) , colnames(estvar) %in% names(intr)] +
                      2*estvar[rownames(estvar) %in% names(main) , colnames(estvar) %in% names(intr)]))
  
  outstorage[[k]] <- cbind(coefs1,ses1,coefs2,ses2)
  k <- k + 1
}

#locs <- c(3,4,5,9,10,11,15,19,20)

# pooled subgroup analysis: four in a row ####
tiff(paste0(outpath,"fig6_subgroups.tif"), width = 19, height = 10, units = 'cm',compression = "lzw", res = 300)
par(mar=c(4,0,1,0),oma=c(1,1,1,0), mfrow=c(1,5))
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=.75, cex.lab = .5)

text(x=0.2, y=c(4,8,14,20),labels=c("SANCTIONING", "VOTING", "ADOPTION", "PROPOSAL"), srt=0, adj=1, xpd=TRUE, cex = .75, font = 2)
text(x=0.2, y=c(16:19),labels=c("Parliament", "Council", "Commission, Parliament, or Council", "(Commission)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=0.2, y=c(10:13),labels=c("Parliament", "Commission", "Council", "(Council and Parliament)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=0.2, y=c(6,7),labels=c("Council unanimity", "(Majority of member states)"), srt=0, adj=1, xpd=TRUE, cex = .75)
text(x=0.2, y=c(1:3),labels=c("EU-representatives and governments", "National courts", "(Court of Justice)"), srt=0, adj=1, xpd=TRUE, cex = .75)


# personal benefit
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"Personal benefit",cex=.75)
legend(-.2, 22, legend=c("perceive no personal benefits", "perceive personal benefits"),  col = c("grey", "black"), cex = .65, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white")
segments(0,0,0,20, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

#locs <- c(18:16, 12:10,6,2:1)

points(rep(0, 4),c(19,13,7,3), pch=16, cex = .5)
points(rep(0, 4),c(19,13,7,3)-.2, pch=16, cex = .5)
segments(outstorage[[1]][,1]-1.96*outstorage[[1]][,2],locs,
         outstorage[[1]][,1]+1.96*outstorage[[1]][,2],locs, lwd = 2, col = "grey")
points(outstorage[[1]][,1],locs, pch=16, cex = .5)

segments(outstorage[[1]][,3]-1.96*outstorage[[1]][,4],locs-.2,
         outstorage[[1]][,3]+1.96*outstorage[[1]][,4],locs-.2, lwd = 2, col = "black")
points(outstorage[[1]][,3],-locs, pch=16, cex = .5)


# national attachment
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"National attachment",cex=.75)
legend(-.2, 22, legend=c("high national attachment", "low national attachment"),  col = c("grey", "black"), cex = .65, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white")
segments(0,0,0,20, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

points(rep(0, 4),c(19,13,7,3), pch=16, cex = .5)
points(rep(0, 4),c(19,13,7,3)-.2, pch=16, cex = .5)

segments(outstorage[[3]][,3]-1.96*outstorage[[3]][,4],locs,
         outstorage[[3]][,3]+1.96*outstorage[[3]][,4],locs, lwd = 2, col = "grey")
points(outstorage[[3]][,3],locs, pch=16, cex = .5)

segments(outstorage[[3]][,1]-1.96*outstorage[[3]][,2],locs-.2,
         outstorage[[3]][,1]+1.96*outstorage[[3]][,2],locs-.2, lwd = 2, col = "black")
points(outstorage[[3]][,1],-locs, pch=16, cex = .5)


# EU knowledge
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"EU knowledge",cex=.75)
legend(-.2, 22, legend=c("low EU knowledge", "high EU knowledge"),  col = c("grey", "black"), cex = .65, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white")
segments(0,0,0,20, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

points(rep(0, 4),c(19,13,7,3), pch=16, cex = .5)
points(rep(0, 4),c(19,13,7,3)-.2, pch=16, cex = .5)

segments(outstorage[[5]][,1]-1.96*outstorage[[5]][,2],locs,
         outstorage[[5]][,1]+1.96*outstorage[[5]][,2],locs, lwd = 2, col = "grey")
points(outstorage[[5]][,1],locs, pch=16, cex = .5)

segments(outstorage[[5]][,3]-1.96*outstorage[[5]][,4],locs-.2,
         outstorage[[5]][,3]+1.96*outstorage[[5]][,4],locs-.2, lwd = 2, col = "black")
points(outstorage[[5]][,3],-locs, pch=16, cex = .5)


# cmp scores eu 
plot(1,1,xlim = c(-.2,.2), ylim = c(0,23), axes = F, xlab = "", ylab = "", main = "", cex.main=1, cex.lab = .5)
text(0,23,"Pro-EU party support",cex=.75)
legend(-.2, 22, legend=c("support for anti-EU party", "support for pro-EU party"),  col = c("grey", "black"), cex = .65, lwd=c(2,2,2,2), box.lwd = 0, box.col = "white")
segments(0,0,0,20, lty=2)
axis(1, at = c(-.2,0,.2), cex.axis = .5)

points(rep(0, 4),c(19,13,7,3), pch=16, cex = .5)
points(rep(0, 4),c(19,13,7,3)-.2, pch=16, cex = .5)

segments(outstorage[[8]][,1]-1.96*outstorage[[8]][,2],locs,
         outstorage[[8]][,1]+1.96*outstorage[[8]][,2],locs, lwd = 2, col = "grey")
points(outstorage[[8]][,1],locs, pch=16, cex = .5)

segments(outstorage[[8]][,3]-1.96*outstorage[[8]][,4],locs-.2,
         outstorage[[8]][,3]+1.96*outstorage[[8]][,4],locs-.2, lwd = 2, col = "black")
points(outstorage[[8]][,3],-locs, pch=16, cex = .5)


title(main = "", outer = T,
      xlab = "Effect on Pr(Institutional design preferred)",
      line = -1, cex.lab = 1, cex.main = .75)
dev.off()







